Redirect View — Pyramid Class-Based Views 1.0 documentation

# Redirect View

class `pyramid_views.views.base.` `RedirectView`(**kwargs)

  A view that provides a redirect on any GET request.

  `permanent` = True
  `url` = None
  `pattern_name` = None
  `query_string` = False
  `get_redirect_url`(*elements, **kw)

    Return the URL redirect to. Keyword arguments from the URL pattern match generating the redirect request are provided as kwargs to this method.